BasicShape

Trait BasicShape 

trait BasicShape {
    // Required method
    fn make_shape(
        &self,
        params: &NormalizeParams,
        values: &ComputedValues,
    ) -> ShapeDef;
}

Required Methods

fn make_shape( &self, params: &NormalizeParams, values: &ComputedValues, ) -> ShapeDef

Creates a complete shape definition.

This function can simply call ShapeDef::new(self.make_path(params, values), Markers::*) with the Markers being set to the appropriate value, depending on whether the shape produces markers or not.

Implementors